News for hackers. Stuff that matters.
Re:GlueList – Fast New Java List Implementation by jkot on Friday August 12, 2016 @11:17AM (#12276362)
Using sun.misc.Unsafe to access array elements would make it much faster. Also ArrayList with preset size is faster for inserting elements.
Re:GlueList – Fast New Java List Implementation by Reason077 on Friday August 12, 2016 @11:43AM (#12276543)
Using sun.misc.Unsafe to access array elements would make it much faster.

sun.misc.Unsafe should not make any difference to performance here. OK, you skip bounds checks, but modern VMs are very good at optimising those away anyway.

Also ArrayList with preset size is faster for inserting elements.

Exactly what I was thinking. The only case this is really going to help is where you don't have an idea of what the size is going to be.

Re:GlueList – Fast New Java List Implementation by jkot on Friday August 12, 2016 @12:11PM (#12276750)
Decompression on byte[] is 3x faster with unsafe. I think modern JVMs are far from optimal.
Re:GlueList – Fast New Java List Implementation by Reason077 on Friday August 12, 2016 @12:19PM (#12276817)
Yes, that may be true for byte[], but there's no primitive types in play here. Java collections hold object types only.